@@ -76,19 +76,20 @@
 use tracing::{debug, trace};
 
 use crate::{
+    ObservableSourceTimedata,
     algorithm::{KalmanControllerMessage, KalmanSourceMessage, SourceController},
     config::SourceConfig,
     source::Measurement,
     time_types::{NtpDuration, NtpTimestamp, PollInterval, PollIntervalLimits},
-    ObservableSourceTimedata,
 };
 
 use core::fmt::Debug;
 
 use super::{
+    SourceSnapshot,
     config::AlgorithmConfig,
     matrix::{Matrix, Vector},
-    sqr, SourceSnapshot,
+    sqr,
 };
 
 #[derive(Debug, Clone, Copy)]
@@ -318,7 +319,7 @@ impl MeasurementNoiseEstimator for AveragingBuffer {
     type MeasurementDelay = NtpDuration;
 
     fn update(&mut self, delay: Self::MeasurementDelay) {
-        self.update(delay.to_seconds())
+        self.update(delay.to_seconds());
     }
 
     fn get_noise_estimate(&self) -> f64 {
@@ -506,10 +507,10 @@ impl<D: Debug + Copy + Clone, N: MeasurementNoiseEstimator<MeasurementDelay = D>
             |mut value, prediction, period| {
                 if let Some(period) = period {
                     while (value - prediction).ventry(0) > period / 2.0 {
-                        value = value - Vector::new_vector([period])
+                        value = value - Vector::new_vector([period]);
                     }
                     while (value - prediction).ventry(0) < -period / 2.0 {
-                        value = value + Vector::new_vector([period])
+                        value = value + Vector::new_vector([period]);
                     }
                 }
 
@@ -522,8 +523,7 @@ impl<D: Debug + Copy + Clone, N: MeasurementNoiseEstimator<MeasurementDelay = D>
 
         trace!(
             stats.observe_probability,
-            stats.weight,
-            "Measurement absorbed"
+            stats.weight, "Measurement absorbed"
         );
 
         (stats.observe_probability, stats.weight, m_delta_t)
@@ -588,8 +588,7 @@ impl<D: Debug + Copy + Clone, N: MeasurementNoiseEstimator<MeasurementDelay = D>
         }
         trace!(
             precision_score = self.precision_score,
-            p,
-            "Wander estimate update"
+            p, "Wander estimate update"
         );
         if self.precision_score <= -algo_config.precision_hysteresis {
             self.clock_wander /= 4.0;
@@ -681,7 +680,6 @@ impl<D: Debug + Copy + Clone, N: MeasurementNoiseEstimator<MeasurementDelay = D>
 }
 
 #[derive(Debug, Clone)]
-#[allow(clippy::large_enum_variant)]
 enum SourceStateInner<
     D: Debug + Copy + Clone,
     N: MeasurementNoiseEstimator<MeasurementDelay = D> + Clone,
@@ -876,7 +874,7 @@ impl<D: Debug + Copy + Clone, N: MeasurementNoiseEstimator<MeasurementDelay = D>
         match &mut self.0 {
             SourceStateInner::Initial(_) => {}
             SourceStateInner::Stable(filter) => {
-                filter.process_frequency_steering(time, steer, period)
+                filter.process_frequency_steering(time, steer, period);
             }
         }
     }
@@ -901,10 +899,10 @@ pub type TwoWayKalmanSourceController<SourceId> =
 pub type OneWayKalmanSourceController<SourceId> = KalmanSourceController<SourceId, (), f64>;
 
 impl<
-        SourceId: Copy,
-        D: Debug + Copy + Clone,
-        N: MeasurementNoiseEstimator<MeasurementDelay = D> + Clone,
-    > KalmanSourceController<SourceId, D, N>
+    SourceId: Copy,
+    D: Debug + Copy + Clone,
+    N: MeasurementNoiseEstimator<MeasurementDelay = D> + Clone,
+> KalmanSourceController<SourceId, D, N>
 {
     pub(super) fn new(
         index: SourceId,
@@ -924,10 +922,10 @@ impl<
 }
 
 impl<
-        SourceId: std::fmt::Debug + Copy + Send + 'static,
-        D: Debug + Copy + Clone + Send + 'static,
-        N: MeasurementNoiseEstimator<MeasurementDelay = D> + Clone + Send + 'static,
-    > SourceController for KalmanSourceController<SourceId, D, N>
+    SourceId: std::fmt::Debug + Copy + Send + 'static,
+    D: Debug + Copy + Clone + Send + 'static,
+    N: MeasurementNoiseEstimator<MeasurementDelay = D> + Clone + Send + 'static,
+> SourceController for KalmanSourceController<SourceId, D, N>
 {
     type ControllerMessage = KalmanControllerMessage;
     type SourceMessage = KalmanSourceMessage<SourceId>;
@@ -970,19 +968,25 @@ impl<
     fn observe(&self) -> super::super::ObservableSourceTimedata {
         self.state
             .snapshot(&self.index, &self.algo_config, self.period)
-            .map(|snapshot| snapshot.observe())
-            .unwrap_or(ObservableSourceTimedata {
-                offset: NtpDuration::ZERO,
-                uncertainty: NtpDuration::MAX,
-                delay: NtpDuration::MAX,
-                remote_delay: NtpDuration::MAX,
-                remote_uncertainty: NtpDuration::MAX,
-                last_update: NtpTimestamp::default(),
-            })
+            .map_or(
+                ObservableSourceTimedata {
+                    offset: NtpDuration::ZERO,
+                    uncertainty: NtpDuration::MAX,
+                    delay: NtpDuration::MAX,
+                    remote_delay: NtpDuration::MAX,
+                    remote_uncertainty: NtpDuration::MAX,
+                    last_update: NtpTimestamp::default(),
+                },
+                |snapshot| snapshot.observe(),
+            )
     }
 }
 
 #[cfg(test)]
+#[expect(
+    clippy::too_many_lines,
+    reason = "Long tests are not really a big problem"
+)]
 mod tests {
     use crate::{packet::NtpLeapIndicator, time_types::NtpInstant};
 
@@ -1244,14 +1248,15 @@ mod tests {
         );
 
         assert!(
-            dbg!((source
-                .snapshot(0_usize, &AlgorithmConfig::default(), None)
-                .unwrap()
-                .state
-                .offset()
-                - 20e-3)
-                .abs())
-                < 1e-7
+            dbg!(
+                (source
+                    .snapshot(0_usize, &AlgorithmConfig::default(), None)
+                    .unwrap()
+                    .state
+                    .offset()
+                    - 20e-3)
+                    .abs()
+            ) < 1e-7
         );
         assert!(
             (source
@@ -1321,14 +1326,15 @@ mod tests {
         );
 
         assert!(
-            dbg!((source
-                .snapshot(0_usize, &AlgorithmConfig::default(), None)
-                .unwrap()
-                .state
-                .offset()
-                - -20e-3)
-                .abs())
-                < 1e-7
+            dbg!(
+                (source
+                    .snapshot(0_usize, &AlgorithmConfig::default(), None)
+                    .unwrap()
+                    .state
+                    .offset()
+                    - -20e-3)
+                    .abs()
+            ) < 1e-7
         );
         assert!(
             (source
@@ -1492,9 +1498,11 @@ mod tests {
             data: [0.0, 0.0, 0.0, 0.0, 0.875e-6, 0.875e-6, 0.875e-6, 0.875e-6],
             next_idx: 0,
         });
-        assert!(source
-            .snapshot(0_usize, &AlgorithmConfig::default(), None)
-            .is_none());
+        assert!(
+            source
+                .snapshot(0_usize, &AlgorithmConfig::default(), None)
+                .is_none()
+        );
         source.update_self_using_measurement(
             &SourceConfig::default(),
             &AlgorithmConfig::default(),
@@ -1829,9 +1837,11 @@ mod tests {
         let base = NtpTimestamp::from_fixed_int(0);
         let basei = NtpInstant::now();
         let mut source = SourceState::new(noise_estimator);
-        assert!(source
-            .snapshot(0_usize, &AlgorithmConfig::default(), None)
-            .is_none());
+        assert!(
+            source
+                .snapshot(0_usize, &AlgorithmConfig::default(), None)
+                .is_none()
+        );
         source.update_self_using_measurement(
             &SourceConfig::default(),
             &AlgorithmConfig::default(),
@@ -2066,9 +2076,11 @@ mod tests {
         let base = NtpTimestamp::from_fixed_int(0);
         let basei = NtpInstant::now();
         let mut source = SourceState::new(AveragingBuffer::default());
-        assert!(source
-            .snapshot(0_usize, &AlgorithmConfig::default(), None)
-            .is_none());
+        assert!(
+            source
+                .snapshot(0_usize, &AlgorithmConfig::default(), None)
+                .is_none()
+        );
         source.update_self_using_measurement(
             &SourceConfig::default(),
             &AlgorithmConfig::default(),
